import type { StoryObj, Meta } from '@storybook/react';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import { NsAccordion, AccordionVariant } from '../..';
import { getAccordionData } from './data';
import { within } from '@storybook/testing-library';
import { expect } from '@storybook/jest';
const meta = {
    title: 'Components/Containers/Accordion',
    component: NsAccordion,
    decorators: [withCenterDecorator],
    argTypes: {
        allowMultipleExpanded: {
            control: 'boolean',
            description: `if true, then multiple sections can remain open at a same time, and if false,
            opening a section will close other sections of the accordion`,
        },
        items: {
            description: ` this should be an array of objects, each object should have 3 properties,
            title, body and isDefaultOpen`,
        },
        variant: {
            control: 'select',
            options: [...Object.values(AccordionVariant)],
        },
        level: {
            control: 'number',
            description: `level = 1 means no padding on left from parent to child,
            level = 2 means padding of 16px, level = 3 means padding of 32px and so on ..`,
        },
    },
    args: {
        variant: AccordionVariant.Basic,
        invert: false,
        level: 2,
    },
} satisfies MetaStory;

export default meta;

type MetaStory = Meta<typeof NsAccordion>;
type Story = StoryObj<typeof meta>;

export const SingleOpen: Story = {
    args: {
        allowMultipleExpanded: false,
        items: getAccordionData(),
        invert: false,
    },
    play: ({ canvasElement }) => {
        const canvas = within(canvasElement);
        const el1 = canvas.getByText('Example - 1 JSX');
        expect(el1).toBeInTheDocument();
        expect(el1.closest('header')).toHaveAttribute('aria-expanded', 'true');
        const el2 = canvas.getByText('Example - 2');
        expect(el2).toBeInTheDocument();
        expect(el2.closest('header')).toHaveAttribute('aria-expanded', 'false');
    },
};

export const MultipleOpen: Story = {
    args: {
        allowMultipleExpanded: true,
        items: getAccordionData(),
    },
};
