/**
 * @author [Vijayaprathap Kumar] (vpkumar@nuskin.com)
 * NsLink.stories.tsx
 * @description NsLink component.
 */

import React from 'react';
import type { StoryObj, Meta } from '@storybook/react';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';

import { NsLink } from './';
import { NsTypography } from '../typography';

type ComponentType = typeof NsLink;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Data Display/NsLink',
    component: NsLink,
    decorators: [withCenterDecorator],
    argTypes: {
        children: {
            control: 'text',
            name: 'Children/Content',
            defaultValue: 'Nuskin Link',
        },
        isSsr: { control: 'boolean' },
    },
    args: {
        ariaLabel: 'alt text',
        href: 'new-page',
        isSsr: false,
    },
} as MetaStory;

export const Links: Story = {
    render: (args: any) => (
        <NsTypography variant="title-l">
            <NsLink {...args} href={args.href} />
        </NsTypography>
    ),
};

export const ReactComponentLink: Story = {
    render: (args: any) => (
        <NsLink {...args} href={args.href} passHref>
            <NsTypography variant="title-l">Test Link</NsTypography>
        </NsLink>
    ),
};
