import React from 'react';
import { render } from '@/test-utils/index';
import NsModal from './NsModal';
import { NsModalData } from './stories/mock';
import { NsModalProps } from './types';

describe('NsModal', () => {
    const onHandleClose = jest.fn();

    const NsModalProp = NsModalData as NsModalProps;

    test('1. check NsModal component open', () => {
        const { getByTestId } = render(<NsModal {...NsModalProp} handleClose={onHandleClose} />);
        expect(getByTestId('nsmodal-dialog')).toBeInTheDocument();
    });

    test('2. should render NsModal default component', () => {
        const { getByTestId } = render(<NsModal {...NsModalProp} handleClose={onHandleClose} />);
        expect(getByTestId('modal-default')).toBeInTheDocument();
    });

    test('3. should render NsModal status component', () => {
        const VariantProps: NsModalProps = {
            ...NsModalProp,
            variant: 'info',
        };
        const { getByTestId } = render(<NsModal {...VariantProps} handleClose={onHandleClose} />);
        expect(getByTestId('modal-status')).toBeInTheDocument();
    });

    test('4. should render NsModal title with close button', () => {
        const { getByTestId } = render(<NsModal {...NsModalProp} handleClose={onHandleClose} />);
        expect(getByTestId('modal-title')).toBeInTheDocument();
        expect(getByTestId('modal-close-button')).toBeInTheDocument();
    });

    test('5. should render NsModal body content', () => {
        const { getByTestId } = render(<NsModal {...NsModalProp} handleClose={onHandleClose} />);
        expect(getByTestId('modal-body-content')).toBeInTheDocument();
    });

    test('6. should render NsModal footer', () => {
        const { getByTestId } = render(<NsModal {...NsModalProp} handleClose={onHandleClose} />);
        expect(getByTestId('modal-footer')).toBeInTheDocument();
    });
});
