import React from 'react'

import type { Meta, StoryObj } from '@storybook/react';
import NsTable from './NsTable';
import { withCenterDecorator } from '../../stories/decorators/withCenterDecorator';
import { Item } from './types';
import { NsIcon } from '../icon';

type ComponentType = typeof NsTable;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;
const headers = [
    {
        label: 'Dessert (100g serving)',
        id: 'name',
        numeric: false,
        sortable: false
    },
    { label: 'Calories', id: 'calories' , numeric: true, sortable: true},
    { label: 'Fat (g)', id: 'fat', numeric: true, sortable: true },
    { label: 'Carbs (g)', id: 'carbs', numeric: true, sortable: true },
    { label: 'Protein (g)', id: 'protein', numeric: true, sortable: true },
    { label: 'Iron (%)', id: 'iron', numeric: false, sortable: true },
];

const items = [
    {
        name: 'Frozen Yogurt',
        calories: 159,
        fat: 6.0,
        carbs: 24,
        protein: 4.0,
        iron: '1%',
    },
    {
        name: 'Ice cream sandwich',
        calories: 237,
        fat: 9.0,
        carbs: 37,
        protein: 4.3,
        iron: '1%',
    },
    {
        name: 'Eclair',
        calories: 262,
        fat: 16.0,
        carbs: 23,
        protein: 6.0,
        iron: '7%',
    },
    {
        name: 'Cupcake',
        calories: 305,
        fat: 3.7,
        carbs: 67,
        protein: 4.3,
        iron: '8%',
    },
    {
        name: 'Gingerbread',
        calories: 356,
        fat: 16.0,
        carbs: 49,
        protein: 3.9,
        iron: '16%',
    },
    {
        name: 'Jelly bean',
        calories: 375,
        fat: 0.0,
        carbs: 94,
        protein: 0.0,
        iron: '0%',
    },
    {
        name: 'Lollipop',
        calories: 392,
        fat: 0.2,
        carbs: 98,
        protein: 0,
        iron: '2%',
    },
    {
        name: 'Honeycomb',
        calories: 408,
        fat: 3.2,
        carbs: 87,
        protein: 6.5,
        iron: '45%',
    },
    {
        name: 'Donut',
        calories: 452,
        fat: 25.0,
        carbs: 51,
        protein: 4.9,
        iron: '22%',
    },
    {
        name: 'KitKat',
        calories: 518,
        fat: 26.0,
        carbs: 65,
        protein: 7,
        iron: '6%',
    },
];

export default {
    title: 'Components/Data Display/NsTable',
    component: NsTable,
    decorators: [withCenterDecorator],
    argTypes: {
        rows: {
            control: 'select',
            options: [5, 10, 25],
        },
    },
    args: {
        headers: headers,
        items: items,
        rows: 5,
        itemKey: 'name',
        rowsPerPageOptions: [5, 10, 25],
        isExpandableAll: true,
        showActions: true,
        showExpandedContent: true,
        loading: false,
        expandableContent: (selectedItem: Item, index: number) => {
            return (
                <div key={index}>
                    <p>
                        Data: {selectedItem.name} , {selectedItem.calories}
                    </p>
                    <p>
                        Index: {index}
                    </p>
                    <p>
                        Expandable: True
                    </p>
                </div>
            )
        },
        actionClick: (row: Item) => {
            const handleClick = (event: React.MouseEvent<HTMLButtonElement>) => {
                event.stopPropagation();
                console.log(row)
            }

            return (
                <button onClick={handleClick}>
                    <NsIcon
                        name='cart'
                        size='medium'
                    />
                </button>
            )
        }
    }
} as MetaStory;

export const NasTable: Story = {};
