import { VariantType, closeSnackbar } from 'notistack';
import { render, screen } from '@/test-utils/index';
import React, { PropsWithChildren, useEffect } from 'react';

import { NsToastProvider, ToastOptions, useToast } from '../';

const ToastWrapper = ({ children }: PropsWithChildren<{}>) => {
    return (
        <NsToastProvider>
            { children }
        </NsToastProvider>
    );
}

const ToastComponent = (props: {
    variant: VariantType;
    message?: string;
    options?: ToastOptions;
}) => {
    const { showToast } = useToast();
    const {
        variant,
        message,
        options,
    } = props;
    useEffect(() => {
        showToast(variant, message, options);
    // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    return (
        <div></div>
    );
};

describe('Toast', () => {
    afterEach(() => {
        closeSnackbar();
    });
    it('should render a toast and displays the message', () => {
        render(
            <ToastWrapper>
                <ToastComponent variant='success' message='Hello' />
            </ToastWrapper>
        );
        expect(screen.queryByText('Hello')).toBeInTheDocument();
    });
    it('should render a success toast', () => {
        const { container } = render(
            <ToastWrapper>
                <ToastComponent variant='success' message='Hello' />
            </ToastWrapper>
        );
        expect(container.querySelector('.notistack-MuiContent-success')).toBeInTheDocument();
    });
    it('should render a error toast', () => {
        const { container } = render(
            <ToastWrapper>
                <ToastComponent variant='error' message='Hello' />
            </ToastWrapper>
        );
        expect(container.querySelector('.notistack-MuiContent-error')).toBeInTheDocument();
    });
    it('should render a info toast', () => {
        const { container } = render(
            <ToastWrapper>
                <ToastComponent variant='info' message='Hello' />
            </ToastWrapper>
        );
        expect(container.querySelector('.notistack-MuiContent-info')).toBeInTheDocument();
    });
    it('it should render a warning toast', () => {
        const { container } = render(
            <ToastWrapper>
                <ToastComponent variant='warning' message='Hello' />
            </ToastWrapper>
        );
        expect(container.querySelector('.notistack-MuiContent-warning')).toBeInTheDocument();
    });
    it('should render a warning toast and disappear after 3 seconds', async () => {
        const { container } = render(
            <ToastWrapper>
                <ToastComponent variant='warning' message='Hello' options={{ autoHideDuration: 3000 }}/>
            </ToastWrapper>
        );
        expect(container.querySelector('.notistack-MuiContent-warning')).toBeInTheDocument();
        await new Promise((r) => setTimeout(r, 4000));
        expect(container.querySelector('.notistack-MuiContent-warning')).not.toBeInTheDocument();
    });
    it('should render a action buttons', async () => {
       
        const { getByTestId } = render(
            <ToastWrapper>
                <ToastComponent variant='warning' message='Hello' options={{ actions: [
                    {
                        label: 'Undo',
                        onClick: () => alert('Undo clicked'),
                    },
                ] }}/>
            </ToastWrapper>
        );
        expect(getByTestId('action-button')).toBeInTheDocument();
    });
    it('should render close button', async () => {
        const { getByTestId } = render(
            <ToastWrapper>
                <ToastComponent variant='warning' message='Hello' options={
                    {showCloseIcon: true,}}
                />
            </ToastWrapper>
        );
        expect(getByTestId('icon')).toBeInTheDocument();
    });
    it('should render a action buttons and close button', async () => {
       
        const { getAllByRole } = render(
            <ToastWrapper>
                <ToastComponent variant='warning' message='Hello' options={
                    { actions: [
                        {
                            label: 'Undo',
                            onClick: () => alert('Undo clicked'),
                        },
                    ],
                    showCloseIcon: true,
                    }}/>
            </ToastWrapper>
        );
        expect(getAllByRole('button')?.length).toBe(2);
    });
});
